@@ -292,13 +292,13 @@ void *mm_core_create(size_t usersize, const char *file)
 
 #if defined(MM_SEMT_FLOCK)
     unlink(fnsem);
-    if ((fdsem = open(fnsem, O_WRONLY|O_CREAT, MM_CORE_FILEMODE)) == -1)
+    if ((fdsem = open(fnsem, O_RDWR|O_CREAT, MM_CORE_FILEMODE)) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to open semaphore file");
 #endif /* MM_SEMT_FLOCK */
 
 #if defined(MM_SEMT_FCNTL)
     unlink(fnsem);
-    if ((fdsem = open(fnsem, O_WRONLY|O_CREAT, MM_CORE_FILEMODE)) == -1)
+    if ((fdsem = open(fnsem, O_RDWR|O_CREAT, MM_CORE_FILEMODE)) == -1)
         FAIL(MM_ERR_CORE|MM_ERR_SYSTEM, "failed to open semaphore file");
 #endif /* MM_SEMT_FCNTL */
 
